% This file is 'ifsoletter.cls', which provides a customized letter
% class for the IFSO

% Copyright (C) 2004 Irish Free Software Organisation

% This file is free software; the Irish Free Software Organisation
% gives unlimited permission to copy and/or distribute it, with or
% without modifications, as long as this notice is preserved.

% This file is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY, to the extent permitted by law; without even
% the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
% PURPOSE.

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ifsoletter} [2004/04/06 v0.7 IFSO Letter CMcG]

% need graphicx for logo
\usepackage[final]{graphicx}

% ifthen package to facilitate switching on and off options
\RequirePackage{ifthen}

% 'gaeilge'option produces an Irish language letterhead
\newboolean{@gaeilge}
\setboolean{@gaeilge}{false}
\DeclareOption{gaeilge}{\setboolean{@gaeilge}{true}}

% 'openletter' option produces a different type of subject heading
\newboolean{@openletter}
\setboolean{@openletter}{false}
\DeclareOption{openletter}{\setboolean{@openletter}{true}}

% process all other options to the class (and base class)
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{letter}}
\ProcessOptions
\LoadClass[a4paper]{letter}

% one of the commands 'englishlabels' or 'gaeilgelabels' will be invoked
% according to whether or not the 'gaeilge' option is specified
\newcommand{\englishlabels}{%
 % IFSO full name and slogan
 \newcommand{\@orgName}{Irish Free Software Organisation}
 \newcommand{\@orgNameCaps}{IRISH FREE SOFTWARE ORGANISATION}
 \newcommand{\@orgSlogan}{``To Promote and Defend Free Software in Ireland''}
 \newcommand{\@orgWeb}{http://www.ifso.info}

%% \newcommand{\yreflabel}{\textsl{Your Ref.}}
%% \newcommand{\ymaillabel}{\textsl{Your letter from}}
%% \newcommand{\myreflabel}{\textsl{Our Ref.}}
 \newcommand{\subjectlabel}{\textsl{Subject}}
 \newcommand{\telephonelabel}{Telephone}
}

\newcommand{\gaeilgelabels}{%
 % IFSO full name and slogan % i18n
 \newcommand{\@orgName}{Irish Free Software Organisation} % i18n
 \newcommand{\@orgNameCaps}{IRISH FREE SOFTWARE ORGANISATION} % i18n
 \newcommand{\@orgSlogan}{``To Promote and Defend Free Software in Ireland''} % i18n
 \newcommand{\@orgWeb}{http://www.ifso.info}

%% \newcommand{\yreflabel}{\textsl{Your Ref.}} % i18n
%% \newcommand{\ymaillabel}{\textsl{Your letter from}} % i18n
%% \newcommand{\myreflabel}{\textsl{Our Ref.}} % i18n
 \newcommand{\subjectlabel}{\textsl{Subject}} % i18n
 \newcommand{\telephonelabel}{Telef\'on} % i18n
}

% choose language for labels
\ifthenelse{\boolean{@gaeilge}}
  {\RequirePackage{gaeilge}\gaeilgelabels}{\englishlabels}

% new internal commands for storing 'label: value' data
%%\newcommand{\@yref}{}     
%%\newcommand{\@ymail}{}
%%\newcommand{\@myref}{}    
\newcommand{\@subject}{}
\newcommand{\@email}{}

% new commands (invoked in the preamble) to set above values
%%\newcommand{\yref}[1]{\renewcommand{\@yref}{\yreflabel: #1}}
%%\newcommand{\ymail}[1]{\renewcommand{\@ymail}{\ymaillabel: #1}}
%%\newcommand{\myref}[1]{\renewcommand{\@myref}{\myreflabel: #1}}
\newcommand{\subject}[1]{%
 \ifthenelse{\boolean{@openletter}}
  {\renewcommand{\@subject}{#1}}
  {\renewcommand{\@subject}{\subjectlabel: #1}}
}
\newcommand{\email}[1]{\renewcommand{\@email}{#1}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% absolute distnaces for headers etc.
\setlength{\textheight}{230mm}  
\setlength{\textwidth}{160mm}
\setlength{\oddsidemargin}{0pt}
\setlength{\evensidemargin}{0pt}
\setlength{\topmargin}{-40pt}   
\setlength{\headheight}{12pt}
\setlength{\headsep}{34pt}

% absolute Computer Modern font specifications
\DeclareFixedFont{\xviisf}{OT1}{cmss}{m}{n}{17}
\DeclareFixedFont{\xiisf}{OT1}{cmss}{m}{n}{12}
\DeclareFixedFont{\xsf}{OT1}{cmss}{m}{n}{10}
\DeclareFixedFont{\viiisf}{OT1}{cmss}{m}{n}{8}

% widthds for the constituent header boxes
\newlength{\leftfield}    \setlength{\leftfield}{43mm}
\newlength{\rightfield}   \setlength{\rightfield}{117mm}

% set widths of 'to' (left) & 'from' (right) address fields
\newlength{\leftaddrfield}  \setlength{\leftaddrfield}{95mm}
\newlength{\rightaddrfield}  \setlength{\rightaddrfield}{65mm}

% saveboxes for storing parts of headers and footers
\newsavebox{\ORG}       
\newsavebox{\org}
\newsavebox{\orglogo}
\newsavebox{\orgsmalllogo}

% large organisation name (plus slogan) for opening page
\sbox{\ORG}{\parbox[t]{\rightfield}{
 {\parbox[t]{\rightfield}{\xviisf \centering \@orgNameCaps}}
 {\parbox[t]{\rightfield}{\xsf \centering \@orgSlogan}}
}}

% large logo
\sbox{\orglogo}
 {\parbox[t]{\leftfield}
  {\includegraphics[width=45mm]{ifsologo.eps}}}

% main header and footer saveboxes
\newsavebox{\orghead}   
\newsavebox{\orgminorhead}   
\newsavebox{\orgfoot}

% header savebox, contains logo and large org name (plus slogan)
\sbox{\orghead}{%
 {\raisebox{-35pt}{\usebox{\orglogo}}}
 {\parbox[t]{\rightfield}{\usebox{\ORG}}}
}

% organisation name (plus slogan) for subsequent pages
\sbox{\org}{
 {\parbox[t]{\textwidth}{\xsf \centering \@orgSlogan}}
}

% small logo
\sbox{\orgsmalllogo}
 {\parbox[t]{\textwidth}
  {\parbox[t]{16mm}
  {\includegraphics[width=16mm]{ifsologo.eps}}}
 }

% header for second and subsequent pages
\sbox{\orgminorhead}{\parbox[t]{\textwidth}{%
 {\parbox[t]{72mm}{\mbox{}}}
 {\usebox{\orgsmalllogo}}\\
 {\parbox[t]{\textwidth}{\xsf \centering \@orgSlogan}}
}}

% footer savebox, contains website address
\sbox{\orgfoot}
 {\parbox{\textwidth}{\viiisf
  \hfill
  {\parbox[t]{50mm}{%
   {\xsf \@orgName\\\@orgWeb}
%%   \par   
%%   \fromname, IFSO Member}} %% this doesn't work as expected
  }}
}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% overrides the structure of a letter firstpage
\renewcommand{\ps@firstpage}
  {\setlength{\headheight}{41pt}%
   \setlength{\headsep}{45pt}%
   \renewcommand{\@oddhead}{\usebox{\orghead}}
   \renewcommand{\@oddfoot}{\raisebox{-10pt}[0pt]
                             {\usebox{\orgfoot}}}
   \renewcommand{\@evenhead}{}\renewcommand{\@evenfoot}{}}

% overrides the structure of letter headings
\renewcommand{\ps@headings}
   {\setlength{\headheight}{51pt}%
    \setlength{\topmargin}{-60pt}%
    \setlength{\headsep}{44pt}%
    \renewcommand{\@oddhead}
       {\parbox{\textwidth}{\usebox{\orgminorhead}\\[10pt]
          \slshape \headtoname{} \toname\hfill\@date\hfill
                                     \pagename{} \thepage\\
          \rule[3pt]{\textwidth}{1pt}}}
    \renewcommand{\@oddfoot}{\usebox{\orgfoot}}
    \renewcommand{\@evenhead}{\@oddhead}
    \renewcommand{\@evenfoot}{\@oddfoot}}

% provides the header and footer commands, in case they're not defined
\providecommand{\@evenhead}{}\providecommand{\@oddhead}{}
\providecommand{\@evenfoot}{}\providecommand{\@oddfoot}{}

% sets the letter style to headings style (always)
\pagestyle{headings}

% override the letter opening (a very complicated affair)
\renewcommand{\opening}[1]{\thispagestyle{firstpage}%
 % recipient name and address (LHS)
 \parbox[t]{\leftaddrfield}
  {\toname\\\toaddress}
 % sender name and address (RHS)
 \parbox[t]{\rightaddrfield}
  {\ifthenelse{\boolean{@openletter}}{}{\fromname\\}\fromaddress
  \ifthenelse{\equal{\telephonenum}{}}
   {}{\\ Tel.: \telcode-\telephonenum}
  \ifthenelse{\equal{\@email}{}}
   {}{\\{\viiisf \@email}}
  \\[5mm] \@date}
  \par
  % letter subject display
  \ifthenelse{\equal{\@subject}{}}
   {} % no subject heading
   {\ifthenelse{\boolean{@openletter}}}
    % if this is an open letter, subject uses a framed box for emphasis
    {\framebox[\textwidth][s]{
     \parbox[t]{\textwidth}{\bfseries \centering \@subject}} \par}
    % otherwise, horizontal rule and simple subject line
    {\rule{\textwidth}{0.6pt}
     \@subject \par}

   \vspace{2\parskip} #1 \par\nobreak
}